Using nlpsig to construct paths of embeddings
=============================================

Once embeddings are obtained, ``nlpsig.PrepareData`` allows the user to construct paths of embeddings by padding.

.. automodule:: nlpsig.data_preparation
   :members:
   :undoc-members:
   :show-inheritance:
